==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/InformalAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.InformalAttribute;
import io.ciera.tool.sql.ooaofooa.interaction.InformalAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassParticipantAttributeSetImpl;

import java.util.Arrays;
import java.util.List;


public class InformalAttributeSetImpl extends InstanceSet<InformalAttributeSet,InformalAttribute> implements InformalAttributeSet {

    // attributes
    @Override
    public void setIa_ID( UniqueId ref_Ia_ID ) throws XtumlException {
        for ( InformalAttribute informalattribute : this ) informalattribute.setIa_ID( ref_Ia_ID );
    }


    // selections
    @Override
    public ClassParticipantAttributeSet R947_is_a_ClassParticipantAttribute() throws XtumlException {
        ClassParticipantAttributeSet classparticipantattributeset = new ClassParticipantAttributeSetImpl();
        for ( InformalAttribute informalattribute : this ) classparticipantattributeset.add( informalattribute.R947_is_a_ClassParticipantAttribute() );
        return classparticipantattributeset;
    }


    @Override
    public InformalAttribute nullElement() {
        return InformalAttributeImpl.EMPTY_INFORMALATTRIBUTE;
    }

    @Override
    public InformalAttributeSet emptySet() {
      return new InformalAttributeSetImpl();
    }

    @Override
    public InformalAttributeSet value() {
        return this;
    }

    @Override
    public List<InformalAttribute> elements() {
        return Arrays.asList(toArray(new InformalAttribute[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/InformalAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.InformalAttribute;
import io.ciera.tool.sql.ooaofooa.interaction.InformalAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassParticipantAttributeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InformalAttributeSetImpl extends InstanceSet<InformalAttributeSet,InformalAttribute> implements InformalAttributeSet {

    public InformalAttributeSetImpl() {
    }

    public InformalAttributeSetImpl(Comparator<? super InformalAttribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setIa_ID( UniqueId ref_Ia_ID ) throws XtumlException {
        for ( InformalAttribute informalattribute : this ) informalattribute.setIa_ID( ref_Ia_ID );
    }


    // selections
    @Override
    public ClassParticipantAttributeSet R947_is_a_ClassParticipantAttribute() throws XtumlException {
        ClassParticipantAttributeSet classparticipantattributeset = new ClassParticipantAttributeSetImpl();
        for ( InformalAttribute informalattribute : this ) classparticipantattributeset.add( informalattribute.R947_is_a_ClassParticipantAttribute() );
        return classparticipantattributeset;
    }


    @Override
    public InformalAttribute nullElement() {
        return InformalAttributeImpl.EMPTY_INFORMALATTRIBUTE;
    }

    @Override
    public InformalAttributeSet emptySet() {
      return new InformalAttributeSetImpl();
    }

    @Override
    public InformalAttributeSet emptySet(Comparator<? super InformalAttribute> comp) {
      return new InformalAttributeSetImpl(comp);
    }

    @Override
    public InformalAttributeSet value() {
        return this;
    }

    @Override
    public List<InformalAttribute> elements() {
        return Arrays.asList(toArray(new InformalAttribute[0]));
    }

}
